==> zzyj-laborservice-impl-3.0.0-20241213.054421-53-sources.jar: com/ejianc/business/itax/controller/SalaryCollectController.java <==
package com.ejianc.business.itax.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.itax.bean.SalaryCollectEntity;
import com.ejianc.business.itax.service.ISalaryCollectService;
import com.ejianc.business.itax.vo.SalaryCollectVO;

/**
 * 工人工资汇总
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("salaryCollect")
public class SalaryCollectController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISalaryCollectService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SalaryCollectVO> saveOrUpdate(@RequestBody SalaryCollectVO saveOrUpdateVO) {
    	SalaryCollectEntity entity = BeanMapper.map(saveOrUpdateVO, SalaryCollectEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

    	service.saveOrUpdate(entity, false);

        service.calculateCollectItax(entity);

    	SalaryCollectVO vo = BeanMapper.map(entity, SalaryCollectVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SalaryCollectVO> queryDetail(Long id) {
    	SalaryCollectEntity entity = service.selectById(id);
    	SalaryCollectVO vo = BeanMapper.map(entity, SalaryCollectVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SalaryCollectVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SalaryCollectVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SalaryCollectVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SalaryCollectVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        //param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        IPage<SalaryCollectEntity> page = service.queryPage(param,false);
        IPage<SalaryCollectVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryCollectVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SalaryCollectEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("SalaryCollect-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refSalaryCollectData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SalaryCollectVO>> refSalaryCollectData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<SalaryCollectEntity> page = service.queryPage(param,false);
        IPage<SalaryCollectVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryCollectVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> zzyj-laborservice-impl-3.0.0-20250218.021957-73-sources.jar: com/ejianc/business/itax/controller/SalaryCollectController.java <==
package com.ejianc.business.itax.controller;

import java.io.Serializable;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.itax.bean.SalaryCollectDetailEntity;
import com.ejianc.business.itax.bean.WorkerEntity;
import com.ejianc.business.itax.service.ISalaryCollectDetailService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.itax.bean.SalaryCollectEntity;
import com.ejianc.business.itax.service.ISalaryCollectService;
import com.ejianc.business.itax.vo.SalaryCollectVO;

/**
 * 工人工资汇总
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("salaryCollect")
public class SalaryCollectController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ISalaryCollectDetailService detailService;

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ISalaryCollectService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<SalaryCollectVO> saveOrUpdate(@RequestBody SalaryCollectVO saveOrUpdateVO) {
    	SalaryCollectEntity entity = BeanMapper.map(saveOrUpdateVO, SalaryCollectEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }

    	service.saveOrUpdate(entity, false);

        service.calculateCollectItax(entity);

    	SalaryCollectVO vo = BeanMapper.map(entity, SalaryCollectVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<SalaryCollectVO> queryDetail(Long id) {
    	SalaryCollectEntity entity = service.selectById(id);
    	SalaryCollectVO vo = BeanMapper.map(entity, SalaryCollectVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<SalaryCollectVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (SalaryCollectVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(SalaryCollectVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<SalaryCollectVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        //param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        IPage<SalaryCollectEntity> page = service.queryPage(param,false);
        IPage<SalaryCollectVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryCollectVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<SalaryCollectEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("SalaryCollect-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refSalaryCollectData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<SalaryCollectVO>> refSalaryCollectData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<SalaryCollectEntity> page = service.queryPage(param,false);
        IPage<SalaryCollectVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), SalaryCollectVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }



    /**
     * @Description 三个月0申报导出
     * @param
     * @Return void
     */
    @RequestMapping(value = "/getWsb3Month", method = RequestMethod.POST)
    @ResponseBody
    public void getWsb3Month(HttpServletRequest request, HttpServletResponse response,@RequestBody SalaryCollectEntity entity) {
        SalaryCollectEntity salaryCollectEntity = service.getById(entity.getId());
        List<WorkerEntity> wsb3Month = service.getWsb3Month(salaryCollectEntity.getBillTime());
        List<WorkerEntity> wsbThisMonth = service.getWsbThisMonth(salaryCollectEntity.getBillTime());

        for (WorkerEntity workerEntity : wsb3Month) {
            workerEntity.setRemark("非正常");
            workerEntity.setOrgName("居民身份证");
            if (workerEntity.getEffectiveStartTime() != null) {
                workerEntity.setProjectName(DateUtil.format(workerEntity.getEffectiveStartTime(), "yyyy-MM-dd"));
            }

        }
        for (WorkerEntity workerEntity : wsbThisMonth) {
            workerEntity.setRemark("非正常");
            workerEntity.setOrgName("居民身份证");
            if (workerEntity.getEffectiveStartTime() != null) {
                workerEntity.setProjectName(DateUtil.format(workerEntity.getEffectiveStartTime(), "yyyy-MM-dd"));
            }
        }
        ArrayList<WorkerEntity> workerEntities = new ArrayList<>();
        workerEntities.addAll(wsb3Month);
        workerEntities.addAll(wsbThisMonth);

        //正常人员（应该新增的人员）
        LambdaQueryWrapper<SalaryCollectDetailEntity> lambdaQueryWrapper1 = new LambdaQueryWrapper<>();
        lambdaQueryWrapper1.eq(SalaryCollectDetailEntity::getPid, entity.getId());
        lambdaQueryWrapper1.eq(SalaryCollectDetailEntity::getUserState,2);
        lambdaQueryWrapper1.eq(SalaryCollectDetailEntity::getDr, 0);
        List<SalaryCollectDetailEntity> rosterEntityList= detailService.list(lambdaQueryWrapper1);
        List<WorkerEntity> workerEntities1 = BeanMapper.mapList(rosterEntityList, WorkerEntity.class);
        for (WorkerEntity salaryCollectDetailEntity : workerEntities1) {
            int i1 = Integer.parseInt(salaryCollectDetailEntity.getIdNum().substring(16, 17));
            if (i1 % 2 == 0){
                //偶数 女
                salaryCollectDetailEntity.setSex("女");
            }else {
                //奇数 男
                salaryCollectDetailEntity.setSex("男");
            }
            salaryCollectDetailEntity.setRemark("正常");
            salaryCollectDetailEntity.setOrgName("居民身份证");
            if (salaryCollectDetailEntity.getEffectiveStartTime() != null) {
                salaryCollectDetailEntity.setProjectName(DateUtil.format(salaryCollectDetailEntity.getEffectiveStartTime(), "yyyy-MM-dd"));
            }
        }
        workerEntities.addAll(workerEntities1);

        Map<String, Object> beans = new HashMap<>();
        beans.put("records", workerEntities);
        ExcelExport.getInstance().export("getWorkerList-export.xlsx", beans, response);
    }

    /**
     * @Description 不存在人员导出
     * @param
     * @Return void
     */
    @RequestMapping(value = "/getUnregist", method = RequestMethod.POST)
    @ResponseBody
    public void getUnregist(HttpServletRequest request, HttpServletResponse response,@RequestBody SalaryCollectEntity entity) {
        LambdaQueryWrapper<SalaryCollectDetailEntity> lambdaQueryWrapper1 = new LambdaQueryWrapper<>();
        lambdaQueryWrapper1.eq(SalaryCollectDetailEntity::getPid, entity.getId());
        lambdaQueryWrapper1.eq(SalaryCollectDetailEntity::getUserState,2);
        lambdaQueryWrapper1.eq(SalaryCollectDetailEntity::getDr, 0);
        List<SalaryCollectDetailEntity> rosterEntityList= detailService.list(lambdaQueryWrapper1);
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", rosterEntityList);
        ExcelExport.getInstance().export("getWsb3Month-export.xlsx", beans, response);
    }
}
